from setuptools import setup, find_packages

setup(
    name='tesis_tn',
    version='0.3',
    packages=find_packages(),
    install_requires=[
    ],
    license='MIT',
    long_description=open('README.md').read(),
)
